@@ -11,7 +11,7 @@ use std::{
 pub struct RequestArgs {
     pub url: String,
     pub body: Option<Vec<u8>>,
-    pub retries: u32,
+    pub retries: u32, // 1 initial + N 'retries'
     pub headers: Option<HashMap<String, String>>,
     pub query_params: Option<HashMap<String, String>>,
     pub accept_gzip_response: bool,
@@ -53,12 +53,12 @@ impl RequestArgs {
 
         let query_params_str = query_params
             .iter()
-            .map(|(k, v)| format!("{}={}", k, v))
+            .map(|(k, v)| format!("{k}={v}"))
             .collect::<Vec<_>>()
             .join("&");
 
         if !query_params_str.is_empty() {
-            url.push_str(&format!("?{}", query_params_str));
+            url.push_str(&format!("?{query_params_str}"));
         }
 
         url
